dijit.focus Test

### Focus/Selection Save/Restore Test

This is for testing whether focus and selection can be saved and restored by the focus manager.

If you press the "Save focus" button, it should save the focus, but not the selection. This is because merely pressing that button makes the focused textarea/input lose focus, which also loses the selection. (We fudge things by saving the previously focused element rather than the currently focused one.)

If you press the "Save focus/selection state after 3 seconds" button, and then focus an input/textarea and select some text, it should (after three seconds) save both the focused element and the selection.

This paragraph contains text to select for testing purposes.

hello there!